# Home

[![Build Status](https://travis-ci.org/sohamb03/trtl-py.svg?branch=master)](https://travis-ci.org/sohamb03/trtl-py) ![Discord](https://img.shields.io/discord/388915017187328002?label=Discord)
 
*trtl-py is a Python Wrapper for the JSON-RPC API of TurtleCoin, which integrates with TurtleCoind and WalletAPI.*

  
## Installation

```sh
pip3 install trtl
```

## Requirements

* Python &gt;= 3.6 
* TurtleCoin version 0.24.0

## Donation

If you would like to support  the project, consider making a donation. :-)

```
TRTLv1bq3QuXxJxqudVdR82uZBc61H3rgNAwZqU3e78TLiaMn8VRSACX9vamnUcG35BkQy6VfwUy5CsV9YNomioPGGyVhHH4DMc
```

## License

[MIT License](https://github.com/sohamb03/trtl-py/blob/master/LICENSE)
